import re
import os


def match_path_if(root_path, regexp):
    """Search from C{root_path} and yield filenames that match C{regexp}.

    Hidden directories are ignored.

    @param root_path: The root path to search from.
    @param regexp: A string containing a regular expression to match
        filenames against.
    """
    return _match_path(root_path, regexp, True)

def match_path_except(root_path, regexp):
    """Search from C{root_path} and yield filenames that don't match C{regexp}.

    Hidden directories are ignored.

    @param root_path: The root path to search from.
    @param regexp: A string containing a regular expression to match
        filenames against.
    """
    return _match_path(root_path, regexp, False)

def _match_path(root_path, regexp, include):
    hidden_directory = re.compile(".*/\..*")
    pattern = re.compile(regexp)
    for directory, subdirectories, filenames in os.walk(root_path):
        if not hidden_directory.match(directory):
            for filename in filenames:
                path = os.path.join(directory, filename)
                match = pattern.match(path)
                if match and include:
                    yield path
                elif not match and not include:
                    yield path
