import os
import tempfile
import shutil


class FakeExpect(object):

    def __init__(self):
        self.commands = []
        self.include_working_directory = False

    def run(self, command, logfile=None, timeout=None):
        data = {"logfile": logfile, "timeout": timeout}
        if self.include_working_directory:
            data["working-directory"] = os.getcwd()
        self.commands.append(("run", command, data))

    def expect(self, pattern):
        self.commands.append(("expect", pattern))


class FilesystemPath(object):

    def __init__(self):
        self.dirname = tempfile.mkdtemp()
        self.counter = 0

    def tear_down(self):
        shutil.rmtree(self.dirname)

    def make_dir(self, path=None):
        path = os.path.join(self.dirname, path) or self.make_path()
        os.mkdir(path)
        return path

    def make_path(self, content=None, path=None):
        if path is None:
            self.counter += 1
            path = "%s/%03d" % (self.dirname, self.counter)
        else:
            path = os.path.join(self.dirname, path)
            directory = os.path.dirname(path)
            if directory != self.dirname and not os.path.isdir(directory):
                os.mkdir(directory)

        if content is not None:
            file = open(path, "w")
            try:
                file.write(content)
            finally:
                file.close()
        return path
