import unittest

from autoppa.configuration import Configuration
from autoppa.testing import FilesystemPath


class ConfigurationTest(unittest.TestCase):

    def setUp(self):
        super(ConfigurationTest, self).setUp()
        self.fs = FilesystemPath()

    def tearDown(self):
        self.fs.tear_down()
        super(ConfigurationTest, self).tearDown()

    def test_from_file(self):
        """
        Factory method L{Configuration.from_file} creates a
        L{Configuration} instance from a configuration file.  The
        order of releases is maintained.
        """
        content = """\
[supertool]
email = John Smith <john@upside.com>
branch = /home/john/src/supertool/production
repository = /home/john/src/supertool
releases = dapper edgy gutsy feisty
"""
        path = self.fs.make_path(content=content)
        configuration = Configuration.from_file(path)
        data = configuration.get_build_target("supertool")
        self.assertEquals(data["email"], "John Smith <john@upside.com>")
        self.assertEquals(data["branch"], "/home/john/src/supertool/production")
        self.assertEquals(data["repository"], "/home/john/src/supertool")
        self.assertEquals(data["releases"], "dapper edgy gutsy feisty")

    def test_get_missing_build_target(self):
        """
        L{Configuration.get_build_target} returns C{None} if the
        specified build target is unknown.
        """
        content = """\
[supertool]
email = John Smith <john@upside.com>
branch = /home/john/src/supertool/production
repository = /home/john/src/supertool
releases = dapper edgy gutsy feisty
"""
        path = self.fs.make_path(content=content)
        configuration = Configuration.from_file(path)
        self.assertEquals(configuration.get_build_target("awesometool"), None)
