import os
import unittest

from autoppa.path import match_path_except, match_path_if
from autoppa.testing import FilesystemPath


class MatchPathExceptTest(unittest.TestCase):

    def setUp(self):
        super(MatchPathExceptTest, self).setUp()
        self.fs = FilesystemPath()

    def tearDown(self):
        self.fs.tear_down()
        super(MatchPathExceptTest, self).tearDown()

    def test_match_path_except(self):
        """
        L{match_path_except} searches from its starting path and
        yields paths for files that don't match the regular
        expression.
        """
        path = self.fs.make_path(content="demo", path="demo")
        self.fs.make_path(content="test", path="test.autoppa")
        self.assertEquals(list(match_path_except(self.fs.dirname,
                                                 ".*\.autoppa")),
                          [path])

    def test_match_subdirectories(self):
        """L{match_path_except} can find matches in subdirectories."""
        path = self.fs.make_path(content="test", path="test/test")
        self.assertEquals(list(match_path_except(self.fs.dirname,
                                                 ".*\.autoppa")),
                          [path])

    def test_match_ignores_hidden_directories(self):
        """L{match_path_except} ignores hidden directories."""
        self.fs.make_path(content="test", path=".test/test")
        self.fs.make_path(content="test", path=".test/wubble/test")
        self.assertEquals(list(match_path_except(self.fs.dirname,
                                                 ".*\.autoppa")),
                          [])


class MatchPathIfTest(unittest.TestCase):

    def setUp(self):
        super(MatchPathIfTest, self).setUp()
        self.fs = FilesystemPath()

    def tearDown(self):
        self.fs.tear_down()
        super(MatchPathIfTest, self).tearDown()

    def test_match_path_if(self):
        """
        L{match_path_if} searches from its starting path and yields
        paths for files that match the regular expression.
        """
        self.fs.make_path(content="demo", path="demo")
        path = self.fs.make_path(content="test", path="test.autoppa")
        self.assertEquals(list(match_path_if(self.fs.dirname, ".*\.autoppa")),
                          [path])

    def test_match_subdirectories(self):
        """L{match_path_if} can find matches in subdirectories."""
        path = self.fs.make_path(content="test", path="test/test.autoppa")
        self.assertEquals(list(match_path_if(self.fs.dirname, ".*\.autoppa")),
                          [path])

    def test_match_ignores_hidden_directories(self):
        """L{match_path_if} ignores hidden directories."""
        self.fs.make_path(content="test", path=".test/test.autoppa")
        self.fs.make_path(content="test", path=".test/wubble/test.autoppa")
        self.assertEquals(list(match_path_if(self.fs.dirname, ".*\.autoppa")),
                          [])
